==> chromium-browser_13.0.782.220~r99552.orig.tar.bz2: chromium-13.0.782.220~r99552/src/chrome/browser/extensions/extension_input_api.h <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_EXTENSIONS_EXTENSION_INPUT_API_H_
#define CHROME_BROWSER_EXTENSIONS_EXTENSION_INPUT_API_H_
#pragma once

#include "chrome/browser/extensions/extension_function.h"

namespace views {
class Widget;
}  // namespace views

// Base class for input APIs.
class InputFunction : public AsyncExtensionFunction {
 public:
  virtual void Run();
  virtual bool RunImpl() = 0;
};

// Note that this experimental API is currently only available for
// TOOLKIT_VIEWS (see chrome/chrome_browser.gypi).
//
// We may eventually support other platforms by adding the necessary
// synthetic event distribution code to this Function.
class SendKeyboardEventInputFunction : public InputFunction {
 public:
  virtual bool RunImpl();
  DECLARE_EXTENSION_FUNCTION_NAME("experimental.input.sendKeyboardEvent");

 private:
  views::Widget* GetTopLevelWidget();
};

#if defined(TOUCH_UI)
class HideKeyboardFunction : public AsyncExtensionFunction {
 public:
  virtual bool RunImpl();
  DECLARE_EXTENSION_FUNCTION_NAME("experimental.input.hideKeyboard");
};
#endif

#if defined(OS_CHROMEOS) && defined(TOUCH_UI)
// Note that this experimental APIs are currently only available for
// TOUCH_UI version of Chrome OS. Please also note that the version of Chrome
// OS is always built with TOOLKIT_VIEWS.
//
// We may eventually support other platforms, especially non TOUCH_UI version
// of Chrome OS.
class SendHandwritingStrokeFunction : public SyncExtensionFunction {
 public:
  virtual bool RunImpl();
  DECLARE_EXTENSION_FUNCTION_NAME("experimental.input.sendHandwritingStroke");
};

class CancelHandwritingStrokesFunction : public SyncExtensionFunction {
 public:
  virtual bool RunImpl();
  DECLARE_EXTENSION_FUNCTION_NAME(
      "experimental.input.cancelHandwritingStrokes");
};
#endif

#endif  // CHROME_BROWSER_EXTENSIONS_EXTENSION_INPUT_API_H_

==> chromium-browser_14.0.835.202~r103287.orig.tar.bz2: chromium-14.0.835.202~r103287/src/chrome/browser/extensions/extension_input_api.h <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_EXTENSIONS_EXTENSION_INPUT_API_H_
#define CHROME_BROWSER_EXTENSIONS_EXTENSION_INPUT_API_H_
#pragma once

#include "chrome/browser/extensions/extension_function.h"

namespace views {
class Widget;
}  // namespace views

// Base class for input APIs.
class InputFunction : public AsyncExtensionFunction {
 public:
  virtual void Run();
  virtual bool RunImpl() = 0;
};

// Note that this experimental API is currently only available for
// TOOLKIT_VIEWS (see chrome/chrome_browser.gypi).
//
// We may eventually support other platforms by adding the necessary
// synthetic event distribution code to this Function.
class SendKeyboardEventInputFunction : public InputFunction {
 public:
  virtual bool RunImpl();
  DECLARE_EXTENSION_FUNCTION_NAME("experimental.input.sendKeyboardEvent");

 private:
  views::Widget* GetTopLevelWidget();
};

#if defined(TOUCH_UI)
class HideKeyboardFunction : public AsyncExtensionFunction {
 public:
  virtual bool RunImpl();
  DECLARE_EXTENSION_FUNCTION_NAME("experimental.input.hideKeyboard");
};

class SetKeyboardHeightFunction : public AsyncExtensionFunction {
 public:
  virtual bool RunImpl();
  DECLARE_EXTENSION_FUNCTION_NAME("experimental.input.setKeyboardHeight");
};
#endif

#if defined(OS_CHROMEOS) && defined(TOUCH_UI)
// Note that this experimental APIs are currently only available for
// TOUCH_UI version of Chrome OS. Please also note that the version of Chrome
// OS is always built with TOOLKIT_VIEWS.
//
// We may eventually support other platforms, especially non TOUCH_UI version
// of Chrome OS.
class SendHandwritingStrokeFunction : public SyncExtensionFunction {
 public:
  virtual bool RunImpl();
  DECLARE_EXTENSION_FUNCTION_NAME("experimental.input.sendHandwritingStroke");
};

class CancelHandwritingStrokesFunction : public SyncExtensionFunction {
 public:
  virtual bool RunImpl();
  DECLARE_EXTENSION_FUNCTION_NAME(
      "experimental.input.cancelHandwritingStrokes");
};
#endif

#endif  // CHROME_BROWSER_EXTENSIONS_EXTENSION_INPUT_API_H_
